@@ -127,9 +127,6 @@ static const GtkActionEntry always_sensitive_entries[] = {
    G_CALLBACK (gtr_open_file_dialog)},
   {"FileRecentFiles", NULL, N_("_Recent Files"), NULL,
    NULL, NULL},
-  {"FileQuitWindow", GTK_STOCK_QUIT, NULL, "<control>Q",
-   N_("Quit the program"),
-   G_CALLBACK (gtr_file_quit)},
 
   /* Edit menu */
   {"EditToolbar", NULL, N_("T_oolbar"), NULL, NULL,
@@ -1735,8 +1732,8 @@ gtr_window_get_active_tab (GtrWindow * window)
  *
  * Gets a list of all tabs in the @window or NULL if there is no tab opened.
  *
- * Returns: (transfer container): a list of all tabs in the @window or NULL if there
- * is no tab opened.
+ * Returns: (transfer container) (element-type Gtranslator.Tab):
+ * a list of all tabs in the @window or NULL if there is no tab opened.
  */
 GList *
 gtr_window_get_all_tabs (GtrWindow * window)
@@ -1861,7 +1858,8 @@ gtr_window_get_active_view (GtrWindow * window)
  *
  * Returns all the views currently present in #GtranslationWindow
  *
- * Return value: (transfer container): a newly allocated list of #GtranslationWindow objects
+ * Return value: (transfer container) (element-type Gtranslator.View):
+ * a newly allocated list of #GtranslationWindow objects
  **/
 GList *
 gtr_window_get_all_views (GtrWindow * window,
